RSBAC commmand-line tools
=========================

For details information about RSBAC visit `RSBAC <http://www.rsbac.org/>`_ webpage.

RSBAC in daily use need some task that the admin have to do. 

For this reason rsbac-tools provides a set of command-line tools. 

Installation
------------

visit `installing <https://bitbucket.org/igraltist/rsbac-tools/src/tip/docs/installing.rst>`_ webpage

Tools
-----

- `rsbac-backup <https://bitbucket.org/igraltist/rsbac-tools/src/tip/docs/scripts/rsbac-backup.rst>`_
- `rsbac-ff-shields <https://bitbucket.org/igraltist/rsbac-tools/src/tip/docs/scripts/rsbac-ff-shields.rst>`_
- `rsbac-run-jail <https://bitbucket.org/igraltist/rsbac-tools/src/tip/docs/scripts/rsbac-run-jail.rst>`_
- `rsbac-ps-jail <https://bitbucket.org/igraltist/rsbac-tools/src/tip/docs/scripts/rsbac-ps-jail.rst>`_
- `rsbac-symlink-redirect <https://bitbucket.org/igraltist/rsbac-tools/src/tip/docs/scripts/rsbac-symlink-redirect.rst>`_

